@@ -1,6 +1,6 @@
 package Any::Template::ProcessDir;
 BEGIN {
-  $Any::Template::ProcessDir::VERSION = '0.04';
+  $Any::Template::ProcessDir::VERSION = '0.05';
 }
 use 5.006;
 use File::Basename;
@@ -24,6 +24,7 @@ has 'process_text'         => ( is => 'ro', isa => 'CodeRef', lazy_build => 1 );
 has 'readme_filename'      => ( is => 'ro', default => 'README' );
 has 'same_dir'             => ( is => 'ro', init_arg => undef );
 has 'source_dir'           => ( is => 'ro' );
+has 'template_file_regex'  => ( is => 'ro', lazy_build => 1 );
 has 'template_file_suffix' => ( is => 'ro', default => '.src' );
 
 sub BUILD {
@@ -39,6 +40,13 @@ sub BUILD {
     }
 }
 
+sub _build_template_file_regex {
+    my $self                 = shift;
+    my $template_file_suffix = $self->template_file_suffix;
+    return
+      defined($template_file_suffix) ? qr/\Q$template_file_suffix\E$/ : qr/.|/;
+}
+
 sub process_dir {
     my ($self) = @_;
 
@@ -68,10 +76,7 @@ sub process_dir {
 sub generate_dest_file {
     my ( $self, $source_file ) = @_;
 
-    my $template_file_suffix = $self->template_file_suffix;
-    my $template_file_regex =
-      defined($template_file_suffix) ? qr/\Q$template_file_suffix\E$/ : qr/.|/;
-
+    my $template_file_regex = $self->template_file_regex;
     substr( ( my $dest_file = $source_file ), 0, length( $self->source_dir ) ) =
       $self->dest_dir;
 
@@ -83,9 +88,12 @@ sub generate_dest_file {
         my $code = $self->process_file;
         $dest_text = $code->( $source_file, $self );
     }
-    else {
+    elsif ( !$self->same_dir ) {
         $dest_text = read_file($source_file);
     }
+    else {
+        return;
+    }
 
     if ( $self->same_dir ) {
         unlink($dest_file);
@@ -151,7 +159,7 @@ Any::Template::ProcessDir -- Process a directory of templates
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
